@@ -8,33 +8,25 @@
     https://octoboxy.com/octobase/
 '''
 
-VERSION             = '0.6'
-
-
-booted              = False   # xyzzy -- move somewhere
+VERSION             = '0.6.4'
 
 
 # Any exceptions we raise should be defined here
 from .              import errors
 
-
 # Massive library of helper functions
 from .              import utils
 
-
 # Fundamental classes from which to build more complex things
 from .fundamentals  import Controller, ControllerMixin, Enum, Registry
 registry            = Registry()
 
-
 # Atomic constants
 from .              import consts
 
-
-# A righteous text markup language
-from .rightdown     import RightDownData, RightDownOptions
-
-
 # Our version of unittests
 from .fundamentals  import TestCase, TestContext, TestModuleContext, TestRunner
 from .              import tests
+
+# A righteous text markup language
+from .rightdown     import RightDownData, RightDownOptions
